@@ -6,12 +6,13 @@
 /**
  * @file api/v1/contexts/index.php
  *
- * Copyright (c) 2014-2021 Simon Fraser University
- * Copyright (c) 2003-2021 John Willinsky
+ * Copyright (c) 2023 Simon Fraser University
+ * Copyright (c) 2023 John Willinsky
  * Distributed under the GNU GPL v3. For full terms see the file docs/COPYING.
  *
  * @ingroup api_v1_contexts
+ *
  * @brief Handle API requests for contexts (journals/presses).
  */
-import('api.v1.contexts.ContextHandler');
-return new ContextHandler();
+
+return new \PKP\handler\APIHandler(new \PKP\API\v1\contexts\PKPContextController());
