@@ -6,8 +6,8 @@
 /**
  * @file api/v1/highlights/index.php
  *
- * Copyright (c) 2014-2023 Simon Fraser University
- * Copyright (c) 2003-2023 John Willinsky
+ * Copyright (c) 2023 Simon Fraser University
+ * Copyright (c) 2023 John Willinsky
  * Distributed under the GNU GPL v3. For full terms see the file docs/COPYING.
  *
  * @ingroup api_v1_highlights
@@ -15,4 +15,4 @@
  * @brief Handle API requests for highlights.
  */
 
-return new \PKP\API\v1\highlights\HighlightsHandler();
+return new \PKP\handler\APIHandler(new \PKP\API\v1\highlights\HighlightsController());
