@@ -19,7 +19,6 @@ declare(strict_types=1);
 namespace PKP\observers\listeners;
 
 use APP\facades\Repo;
-use APP\publication\Publication;
 use Illuminate\Events\Dispatcher;
 use PKP\context\Context;
 use PKP\observers\events\PublicationPublished;
@@ -43,14 +42,11 @@ class VersionDois
         $context = $event->context;
 
         $doisEnabled = $context->getData(Context::SETTING_ENABLE_DOIS);
+
         if (!$doisEnabled) {
             return;
         }
 
-        $doiCreationTime = $context->getData(Context::SETTING_DOI_CREATION_TIME);
-        if ($doiCreationTime === Repo::doi()::CREATION_TIME_NEVER) {
-            return;
-        }
         $_failureResults = Repo::submission()->createDois($submission);
     }
 }
