@@ -1,4 +1,5 @@
 <?php
+
 /**
  * @file classes/user/Collector.php
  *
@@ -15,18 +16,23 @@ namespace PKP\user;
 
 use APP\core\Application;
 use Carbon\Carbon;
+use Exception;
+use Illuminate\Database\MariaDbConnection;
 use Illuminate\Database\MySqlConnection;
+use Illuminate\Database\PostgresConnection;
 use Illuminate\Database\Query\Builder;
 use Illuminate\Database\Query\JoinClause;
 use Illuminate\Support\Collection;
 use Illuminate\Support\Facades\DB;
 use Illuminate\Support\LazyCollection;
 use InvalidArgumentException;
+use PKP\core\Core;
 use PKP\core\interfaces\CollectorInterface;
-use PKP\core\PKPString;
 use PKP\facades\Locale;
 use PKP\identity\Identity;
 use PKP\plugins\Hook;
+use PKP\user\enums\UserMastheadStatus;
+use PKP\userGroup\relationships\enums\UserUserGroupStatus;
 
 /**
  * @template T of User
@@ -42,11 +48,12 @@ class Collector implements CollectorInterface
 
     public const STATUS_ACTIVE = 'active';
     public const STATUS_DISABLED = 'disabled';
-    public const STATUS_ALL = null;
+    public const STATUS_ALL = 'all';
 
     public DAO $dao;
 
     public string $orderBy = self::ORDERBY_ID;
+    public array $orderByUserGroupIds = [];
     public string $orderDirection = 'ASC';
     public ?array $orderLocales = null;
     public ?array $userGroupIds = null;
@@ -64,7 +71,7 @@ class Collector implements CollectorInterface
     public ?array $settings = null;
     public ?string $searchPhrase = null;
     public ?array $excludeSubmissionStage = null;
-    public ?array $excludeRoles = null;
+    public ?array $excludeUserGroupIds = null;
     public ?array $assignedTo = null;
     public ?int $reviewerRating = null;
     public ?int $reviewsCompleted = null;
@@ -73,6 +80,8 @@ class Collector implements CollectorInterface
     public ?array $reviewsActive = null;
     public ?int $count = null;
     public ?int $offset = null;
+    public UserUserGroupStatus $userUserGroupStatus = UserUserGroupStatus::STATUS_ACTIVE;
+    public UserMastheadStatus $userMastheadStatus = UserMastheadStatus::STATUS_ALL;
 
     /**
      * Constructor
@@ -202,7 +211,6 @@ class Collector implements CollectorInterface
         return $this;
     }
 
-
     /**
      * Limit results to users with user groups in these context IDs
      */
@@ -254,12 +262,29 @@ class Collector implements CollectorInterface
     }
 
     /**
-     * Retrieve a set of users not assigned to the given roles
-     * (Replaces UserGroupDAO::getUsersNotInRole)
+     * Retrieve a set of users not assigned to the given user groups
      */
-    public function filterExcludeRoles(?array $excludedRoles): self
+    public function filterExcludeUserGroupIds(?array $excludeUserGroupIds): self
     {
-        $this->excludeRoles = $excludedRoles;
+        $this->excludeUserGroupIds = $excludeUserGroupIds;
+        return $this;
+    }
+
+    /**
+     * Filter by user's role status
+     */
+    public function filterByUserUserGroupStatus(UserUserGroupStatus $userUserGroupStatus): self
+    {
+        $this->userUserGroupStatus = $userUserGroupStatus;
+        return $this;
+    }
+
+    /**
+     * Filter by user's masthead status for the given role
+     */
+    public function filterByUserMastheadStatus(UserMastheadStatus $userMastheadStatus): self
+    {
+        $this->userMastheadStatus = $userMastheadStatus;
         return $this;
     }
 
@@ -358,6 +383,17 @@ class Collector implements CollectorInterface
         return $this;
     }
 
+    /**
+     * Order the results additionally by user group ID
+     *
+     * @param array $userGroupIds The IDs in the order the user query result should be ordered by
+     */
+    public function orderByUserGroupIds(array $userGroupIds): self
+    {
+        $this->orderByUserGroupIds = $userGroupIds;
+        return $this;
+    }
+
     /**
      * Limit the number of objects retrieved
      */
@@ -379,6 +415,8 @@ class Collector implements CollectorInterface
 
     /**
      * @copydoc CollectorInterface::getQueryBuilder()
+     *
+     * @hook User::Collector [[$query, $this]]
      */
     public function getQueryBuilder(): Builder
     {
@@ -440,27 +478,75 @@ class Collector implements CollectorInterface
      */
     protected function buildUserGroupFilter(Builder $query): self
     {
-        if ($this->userGroupIds === null && $this->roleIds === null && $this->contextIds === null && $this->workflowStageIds === null) {
+        if ($this->userGroupIds === null &&
+            $this->roleIds === null &&
+            $this->contextIds === null &&
+            $this->workflowStageIds === null &&
+            $this->userMastheadStatus === UserMastheadStatus::STATUS_ALL) {
+
             return $this;
         }
 
-        $userGroupsSubquery = fn (Builder $query) => $query->from('user_user_groups as uug')
+        $currentDateTime = Core::getCurrentDate();
+        if ($this->status === self::STATUS_ALL) {
+            $this->userUserGroupStatus = UserUserGroupStatus::STATUS_ALL;
+        }
+
+        $subQuery = DB::table('user_user_groups as uug')
             ->join('user_groups AS ug', 'uug.user_group_id', '=', 'ug.user_group_id')
             ->whereColumn('uug.user_id', '=', 'u.user_id')
-            ->when($this->userGroupIds !== null, fn (Builder $query) => $query->whereIn('uug.user_group_id', $this->userGroupIds))
+            ->when($this->userGroupIds !== null, fn ($subQuery) => $subQuery->whereIn('uug.user_group_id', $this->userGroupIds))
             ->when(
                 $this->workflowStageIds !== null,
-                fn (Builder $query) => $query
+                fn ($subQuery) => $subQuery
                     ->join('user_group_stage AS ugs', 'ug.user_group_id', '=', 'ugs.user_group_id')
                     ->whereIn('ugs.stage_id', $this->workflowStageIds)
             )
-            ->when($this->roleIds !== null, fn ($query) => $query->whereIn('ug.role_id', $this->roleIds))
-            ->when($this->contextIds !== null, fn ($query) => $query->whereIn('ug.context_id', $this->contextIds));
+            ->when($this->roleIds !== null, fn ($subQuery) => $subQuery->whereIn('ug.role_id', $this->roleIds))
+            ->when($this->contextIds !== null, fn ($subQuery) => $subQuery->whereIn(DB::raw('COALESCE(ug.context_id, 0)'), array_map(intval(...), $this->contextIds)))
+            ->when(
+                $this->userUserGroupStatus === UserUserGroupStatus::STATUS_ACTIVE,
+                fn (Builder $subQuery) =>
+                $subQuery->where(
+                    fn (Builder $subQuery) =>
+                    $subQuery->where('uug.date_start', '<=', $currentDateTime)
+                        ->orWhereNull('uug.date_start')
+                )
+                    ->where(
+                        fn (Builder $subQuery) =>
+                        $subQuery->where('uug.date_end', '>', $currentDateTime)
+                            ->orWhereNull('uug.date_end')
+                    )
+            )
+            ->when(
+                $this->userUserGroupStatus === UserUserGroupStatus::STATUS_ENDED,
+                fn (Builder $subQuery) =>
+                $subQuery->whereNotNull('uug.date_end')
+                    ->where('uug.date_end', '<=', $currentDateTime)
+            )
+            ->when(
+                $this->userMastheadStatus === UserMastheadStatus::STATUS_NULL,
+                fn (Builder $subQuery) =>
+                    $subQuery->whereNull('uug.masthead')
+            )
+            ->when(
+                $this->userMastheadStatus === UserMastheadStatus::STATUS_ON,
+                fn (Builder $subQuery) =>
+                    $subQuery->where('ug.masthead', 1)
+                        ->where('uug.masthead', 1)
+            )
+            ->when(
+                $this->userMastheadStatus === UserMastheadStatus::STATUS_OFF,
+                fn (Builder $subQuery) =>
+                    $subQuery->where('ug.masthead', 0)
+                        ->orWhere('uug.masthead', 1)
+                        ->orWhereNull('uug.masthead')
+            );
 
-        $query->whereExists(fn (Builder $query) => $userGroupsSubquery($query));
+        $query->whereExists($subQuery);
 
-        if ($this->excludeRoles != null) {
-            $query->whereNotExists(fn (Builder $query) => $userGroupsSubquery($query)->whereIn('ug.role_id', $this->excludeRoles));
+        if ($this->excludeUserGroupIds != null) {
+            $query->whereNotExists(fn (Builder $query) => $query->from('user_user_groups as xuug')->whereColumn('xuug.user_id', '=', 'u.user_id')->whereIn('xuug.user_group_id', $this->excludeUserGroupIds));
         }
 
         return $this;
@@ -490,6 +576,7 @@ class Collector implements CollectorInterface
         if ($this->excludeSubmissionStage === null) {
             return $this;
         }
+        $currentDateTime = Core::getCurrentDate();
         $query->whereExists(
             fn (Builder $query) => $query->from('user_user_groups', 'uug')
                 ->join('user_group_stage AS ugs', 'ugs.user_group_id', '=', 'uug.user_group_id')
@@ -503,6 +590,41 @@ class Collector implements CollectorInterface
                 ->where('uug.user_group_id', '=', $this->excludeSubmissionStage['user_group_id'])
                 ->where('ugs.stage_id', '=', $this->excludeSubmissionStage['stage_id'])
                 ->whereNull('sa.user_group_id')
+                ->when(
+                    $this->userUserGroupStatus === UserUserGroupStatus::STATUS_ACTIVE,
+                    fn (Builder $query) =>
+                    $query->where(
+                        fn (Builder $query) =>
+                        $query->where('uug.date_start', '<=', $currentDateTime)
+                            ->orWhereNull('uug.date_start')
+                    )
+                        ->where(
+                            fn (Builder $query) =>
+                            $query->where('uug.date_end', '>', $currentDateTime)
+                                ->orWhereNull('uug.date_end')
+                        )
+                )
+                ->when(
+                    $this->userUserGroupStatus === UserUserGroupStatus::STATUS_ENDED,
+                    fn (Builder $query) =>
+                    $query->whereNotNull('uug.date_end')
+                        ->where('uug.date_end', '<=', $currentDateTime)
+                )
+                ->when(
+                    $this->userMastheadStatus === UserMastheadStatus::STATUS_NULL,
+                    fn (Builder $query) =>
+                        $query->whereNull('uug.masthead')
+                )
+                ->when(
+                    $this->userMastheadStatus === UserMastheadStatus::STATUS_ON,
+                    fn (Builder $query) =>
+                        $query->where('uug.masthead', 1)
+                )
+                ->when(
+                    $this->userMastheadStatus === UserMastheadStatus::STATUS_OFF,
+                    fn (Builder $query) =>
+                        $query->where('uug.masthead', 1)
+                )
         );
         return $this;
     }
@@ -537,9 +659,14 @@ class Collector implements CollectorInterface
         }
 
         $disableSharedReviewerStatistics = (bool) Application::get()->getRequest()->getSite()->getData('disableSharedReviewerStatistics');
-        $dateDiff = fn (string $dateA, string $dateB): string => DB::connection() instanceof MySqlConnection
-            ? "DATEDIFF({$dateA}, {$dateB})"
-            : "DATE_PART('day', {$dateA} - {$dateB})";
+
+        $dateDiff = fn (string $dateA, string $dateB): string => match (true) {
+            DB::connection() instanceof MySqlConnection,
+            DB::connection() instanceof MariaDbConnection
+                => "DATEDIFF({$dateA}, {$dateB})",
+            DB::connection() instanceof PostgresConnection
+                => "DATE_PART('day', {$dateA} - {$dateB})"
+        };
 
         $query->leftJoinSub(
             fn (Builder $query) => $query->from('review_assignments', 'ra')
@@ -598,7 +725,7 @@ class Collector implements CollectorInterface
         // Settings where the search will be performed
         $settings = [Identity::IDENTITY_SETTING_GIVENNAME, Identity::IDENTITY_SETTING_FAMILYNAME, 'preferredPublicName', 'affiliation', 'biography', 'orcid'];
         // Break words by whitespace, trims and escapes "%" and "_"
-        $words = array_map(fn (string $word) => '%' . addcslashes($word, '%_') . '%', PKPString::regexp_split('/\s+/', $searchPhrase));
+        $words = array_map(fn (string $word) => '%' . addcslashes($word, '%_') . '%', preg_split('/\s+/u', $searchPhrase));
         foreach ($words as $word) {
             $query->where(
                 fn ($query) => $query->whereRaw('LOWER(u.username) LIKE LOWER(?)', [$word])
@@ -615,6 +742,17 @@ class Collector implements CollectorInterface
                             ->whereColumn('ui.user_id', '=', 'u.user_id')
                             ->whereRaw('LOWER(cves.setting_value) LIKE LOWER(?)', [$word])
                     )
+                    ->orWhereExists(
+                        fn(Builder $query) => $query->from('user_user_groups', 'uug')
+                            ->join('user_groups AS ug', 'uug.user_group_id', '=', 'ug.user_group_id')
+                            ->whereColumn('uug.user_id', '=', 'u.user_id')
+                            ->whereExists(
+                                fn(Builder $query) => $query->from('user_group_settings', 'ugs')
+                                    ->whereColumn('ugs.user_group_id', '=', 'ug.user_group_id')
+                                    ->where('ugs.setting_name', '=', 'name')
+                                    ->whereRaw('LOWER(ugs.setting_value) LIKE LOWER(?)', [$word])
+                            )
+                    )
             );
         }
 
@@ -626,6 +764,24 @@ class Collector implements CollectorInterface
      */
     protected function buildOrderBy(Builder $query): self
     {
+        if (!empty($this->orderByUserGroupIds)) {
+            $query->addSelect('uugob.user_group_id')
+                ->leftJoin('user_user_groups AS uugob', 'uugob.user_id', '=', 'u.user_id');
+            switch (DB::getDriverName()) {
+                case 'mysql':
+                case 'mariadb':
+                    $userGroupOrderBy = implode(', ', $this->orderByUserGroupIds);
+                    $query->orderByRaw("FIELD(uugob.user_group_id, {$userGroupOrderBy}) ASC");
+                    break;
+                case 'pgsql':
+                    $userGroupOrderBy = array_map(fn ($item) => 'uugob.user_group_id=' . $item, $this->orderByUserGroupIds);
+                    $userGroupOrderBy = implode(', ', $userGroupOrderBy);
+                    $query->orderByRaw("({$userGroupOrderBy}) ASC");
+                    break;
+                default: throw new Exception('Unexpected database driver!');
+            }
+        }
+
         $orderByFields = [self::ORDERBY_ID => 'u.user_id'];
         if ($orderByField = $orderByFields[$this->orderBy] ?? null) {
             $query->orderBy($orderByField, $this->orderDirection);
