@@ -1,9 +1,9 @@
 /**
  * @file js/controllers/TabHandler.js
  *
- * Copyright (c) 2014-2019 Simon Fraser University
- * Copyright (c) 2000-2019 John Willinsky
- * Distributed under the GNU GPL v2. For full terms see the file docs/COPYING.
+ * Copyright (c) 2014-2021 Simon Fraser University
+ * Copyright (c) 2000-2021 John Willinsky
+ * Distributed under the GNU GPL v3. For full terms see the file docs/COPYING.
  *
  * @class TabHandler
  * @ingroup js_controllers
@@ -27,7 +27,8 @@
 	 * @param {Object} options Handler options.
 	 */
 	$.pkp.controllers.TabHandler = function($tabs, options) {
-		var pageUrl, pageAnchor, pattern, pageAnchors, tabAnchors, i;
+		var pageUrl, pageAnchor, pattern, pageAnchors, tabAnchors, i,
+				self = this;
 
 		this.parent($tabs, options);
 
@@ -37,7 +38,6 @@
 		this.bind('tabscreate', this.tabsCreate);
 		this.bind('tabsbeforeload', this.tabsBeforeLoad);
 		this.bind('tabsload', this.tabsLoad);
-		this.bind('containerReloadRequested', this.tabsReloadRequested);
 		this.bind('addTab', this.addTab);
 
 		if (options.emptyLastTab) {
@@ -63,10 +63,10 @@
 		// Render the tabs as jQueryUI tabs.
 		$tabs.tabs({
 			// Enable AJAX-driven tabs with JSON messages.
-			ajaxOptions: {
-				dataType: 'json',
-				cache: false,
-				dataFilter: this.callbackWrapper(this.dataFilter)
+			beforeLoad: function(event, ui) {
+				ui.ajaxSettings.dataType = 'json';
+				ui.jqXHR.setRequestHeader('Accept', 'application/json');
+				ui.ajaxSettings.dataFilter = self.callbackWrapper(self.dataFilter);
 			},
 			disabled: options.disabled,
 			active: options.selected
@@ -129,17 +129,20 @@
 		var unsavedForm = false;
 		this.$currentTab_.find('form').each(function(index) {
 
-			var handler = $.pkp.classes.Handler.getHandler($('#' + $(this).attr('id')));
-			if (handler.formChangesTracked) {
-				unsavedForm = true;
-				return false; // found an unsaved form, no need to continue with each().
+			if ($.pkp.classes.Handler.hasHandler($('#' + $(this).attr('id')))) {
+				var handler = $.pkp.classes.Handler.getHandler(
+						$('#' + $(this).attr('id')));
+				if (handler.formChangesTracked) {
+					unsavedForm = true;
+					return false; // found an unsaved form, no need to continue with each().
+				}
 			}
 		});
 
 		this.$currentTab_.find('.hasDatepicker').datepicker('hide');
 
 		if (unsavedForm) {
-			if (!confirm($.pkp.locale.form_dataHasChanged)) {
+			if (!confirm(pkp.localeKeys['form.dataHasChanged'])) {
 				return false;
 			} else {
 				this.trigger('unregisterAllForms');
@@ -265,32 +268,6 @@
 	};
 
 
-	/**
-	 * Callback that processes data returned by the server when
-	 * a 'tabsReloadRequested' event is bubbled up from a widget
-	 * on a tab.
-	 *
-	 * This is useful if you have a tabbed form on a modal and you
-	 * wish to reload the entire tabbed interface when one form is
-	 * submitted. Since this reloads the templates for the tabs you
-	 * have the opportunity to alter their state.
-	 *
-	 * @param {HTMLElement} divElement The parent DIV element
-	 *  which contains the tabs.
-	 * @param {Event} event The triggered event (tabsReloadRequested).
-	 * @param {{tabsUrl: string}} jsonContent The tabs ui data.
-	 */
-	$.pkp.controllers.TabHandler.prototype.tabsReloadRequested =
-			function(divElement, event, jsonContent) {
-
-		var $element = this.getHtmlElement(),
-				self = this;
-		$.get(jsonContent.tabsUrl, function(data) {
-			self.replaceWith(data.content);
-		});
-	};
-
-
 	/**
 	 * Callback that processes data returned by the server when
 	 * an 'addTab' event is received.
@@ -313,7 +290,7 @@
 						.attr('href', jsonContent.url),
 				$closeSpanElement = $('<a/>')
 						.addClass('close')
-						.text($.pkp.locale.common_close)
+						.text(pkp.localeKeys['common.close'])
 						.attr('href', '#'),
 				$liElement = $('<li/>')
 						.append($anchorElement)
@@ -331,7 +308,7 @@
 				var handler = $.pkp.classes.Handler.getHandler($(this));
 				if (handler.formChangesTracked) {
 					// Confirm before proceeding
-					if (!confirm($.pkp.locale.form_dataHasChanged)) {
+					if (!confirm(pkp.localeKeys['form.dataHasChanged'])) {
 						unsavedForm = true;
 						return false;
 					}
@@ -389,5 +366,4 @@
 	};
 
 
-/** @param {jQuery} $ jQuery closure. */
 }(jQuery));
